@@ -397,6 +397,7 @@ def simulate(ip, sim_job):
     sim_str = common.get_simulator_short_name(sim_job.simulator)
     global sem
     start = common.timestamp()
+    sim_job.timestamp_start = start
     log_sim_start_history(ip, sim_job, start)
     if sim_job.is_regression:
         ip_dir_name = f"{ip.vendor}__{ip.name}__{sim_job.regression_name}__{sim_job.regression_timestamp}"
@@ -405,9 +406,11 @@ def simulate(ip, sim_job):
         ip_dir_name = f"{ip.vendor}__{ip.name}"
         sim_out = cfg.sim_output_dir + "/" + sim_str + "/sim_wd/" + ip_dir_name
     do_simulate(ip, sim_job, sim_out)
+    end = common.timestamp()
+    sim_job.timestamp_end = end
     if not sim_job.dry_run:
         sem.acquire()
-        log_sim_end_history(ip, sim_job, start, common.timestamp())
+        log_sim_end_history(ip, sim_job, start, end)
         sem.release()
 
 
@@ -470,6 +473,7 @@ def gen_image_flist(ip, vendor, name, flist_path, sim_job, local):
         for arg in arg_list:
             arg_list_str = arg_list_str + f" {arg}"
         if cfg.dbg:
+            arg_list_str += " -g"
             arg_list = [f"dsim -v -a '{arg_list_str}'"]
         else:
             arg_list = [f"dsim -a '{arg_list_str}'"]
@@ -586,6 +590,7 @@ def cmp_flist(vendor, name, flist_path, deps, sim_job, local, licensed=True):
         for arg in arg_list:
             arg_list_str = arg_list_str + f" {arg}"
         if cfg.dbg:
+            arg_list_str += " -g"
             arg_list = [f"dvlcom -v -a '{arg_list_str}'"]
         else:
             arg_list = [f"dvlcom -a '{arg_list_str}'"]
@@ -750,6 +755,7 @@ def do_elab(ip, sim_job, wd):
         for arg in arg_list:
             arg_list_str = arg_list_str + f" {arg}"
         if cfg.dbg:
+            arg_list_str += " -g"
             arg_list = [f"dsim -v -a '{arg_list_str}'"]
         else:
             arg_list = [f"dsim -a '{arg_list_str}'"]
@@ -845,7 +851,8 @@ def do_simulate(ip, sim_job, wd):
     common.create_dir(tests_results_path)
     common.create_dir(tests_results_path + "/uvmx_logs")
     if sim_job.simulator == common.simulators_enum.METRICS:
-        common.create_dir(mdc_tests_results_path + "/uvmx_logs")
+        common.create_dir(cfg.project_dir + "/" + mdc_tests_results_path)
+        common.create_dir(cfg.project_dir + "/" + mdc_tests_results_path + "/uvmx_logs")
     sim_job.results_path = tests_results_path
     sim_job.results_dir_name = test_result_dir
     if sim_job.waves:
