@@ -29,6 +29,7 @@ from datetime import datetime
 bar = None
 sem = None
 sem_cfg = None
+test_id = 0
 
 
 class TestSuite:
@@ -210,9 +211,12 @@ class TestSuite:
                                     if type(regr_item['args']) is not list:
                                         common.fatal(f"Regression entry args is not list: '{set}.{group}.{test}.{regr}'")
                                     args = regr_item['args']
+                                    final_args = []
                                     for arg in args:
                                         if not isinstance(args[arg], str):
                                             common.fatal(f"Regression entry args entry is not string: '{set}.{group}.{test}.{regr}'")
+                                        final_args.append(arg)
+                                    args = final_args
                                 
                                 if type(regr_item['seeds']) is int:
                                     # Specifying how many seeds to run
@@ -403,7 +407,9 @@ class Regression:
         self.max_errors   = 1
     
     def add_test(self, name, seed, args):
-        test = RegressionTest(name, self, self.group, self.set, self.suite, seed, args)
+        global test_id
+        test = RegressionTest(test_id, name, self, self.group, self.set, self.suite, seed, args)
+        test_id += 1
         self.tests.append(test)
         common.dbg(f"Test '{name}' added to group '{self.group.name}'")
     
@@ -433,7 +439,8 @@ class Regression:
 class RegressionTest:
     """Regression Test model"""
 
-    def __init__(self, name, regression, test_group, set, suite, seed, args):
+    def __init__(self, id, name, regression, test_group, set, suite, seed, args):
+        self.id         = id
         self.name       = name
         self.regression = regression
         self.test_group = test_group
@@ -447,6 +454,7 @@ class RegressionTest:
         sim_job.is_regression   = True
         sim_job.regression_name = cfg.regression_name
         sim_job.regression_timestamp = self.suite.timestamp
+        sim_job.id         = self.id
         sim_job.test       = self.name
         sim_job.seed       = self.seed
         sim_job.compile    = False
@@ -498,7 +506,6 @@ def main(ip_str, target_name, regression, simulator, dry_mode):
     if deps_to_install > 0:
         common.fatal(f"You must first install this IP's dependencies ({deps_to_install}): `mio install {name}`")
     
-    timestamp_start = datetime.now()
     test_suite = scan_target_ip_for_test_suite(ip, simulator)
     if test_suite.target_name != "*":
         if test_suite.target_name != target_name:
@@ -506,6 +513,8 @@ def main(ip_str, target_name, regression, simulator, dry_mode):
     regression = test_suite.get_regression(cfg.cli_args.regr)
     regression.reduce()
     tests      = regression.get_tests()
+    tests_yml_path = write_tests_yml(ip, target_name, test_suite, regression, tests, regression.suite.timestamp, dry_mode)
+    timestamp_start = datetime.now()
     prep_target_ip(ip, target_name, test_suite, simulator)
     
     sim_job_list = []
@@ -514,6 +523,8 @@ def main(ip_str, target_name, regression, simulator, dry_mode):
     
     launch_sim_jobs(ip, target_name, test_suite, regression, sim_job_list, dry_mode)
     timestamp_end = datetime.now()
+    timestamp_end_str = timestamp_end.strftime("%Y/%m/%d-%H:%M:%S")
+    update_tests_yml(tests_yml_path, ip, target_name, test_suite, regression, sim_job_list, timestamp_end_str, dry_mode)
     if not dry_mode:
         regr_results = results.main(f"{ip.vendor}/{ip.name}", "", True, test_suite.filename, regression.name, test_suite.timestamp)
         cov_report_path = cov.gen_cov_report(f"{ip.vendor}/{ip.name}", True, test_suite.filename, regression.name, test_suite.timestamp)
@@ -681,6 +692,70 @@ def parse_test_suite_file(ip, simulator, file):
     return test_suite
 
 
+def write_tests_yml(ip, target_name, test_suite, regression, tests, timestamp_start, dry_mode):
+    ip_str = f"{ip.vendor}/{ip.name}"
+    ip_dir_name = f"{ip.vendor}__{ip.name}"
+    results_path = cfg.regr_results_dir + "/" + ip.name + "__" + regression.name + "__" + timestamp_start
+    common.create_dir(results_path)
+    tests_yml_path = f"{results_path}/tests.yml"
+    tests_yml = {}
+    tests_yml['vendor'         ] = ip.vendor
+    tests_yml['ip'             ] = ip.name
+    tests_yml['target_name'    ] = target_name
+    tests_yml['timestamp_start'] = timestamp_start
+    tests_yml['regression_name'] = regression.name
+    tests_yml['test_suite_name'] = test_suite.name
+    tests_yml['num_tests'      ] = len(tests)
+    #tests_yml['waves'          ] = regression.set
+    tests_yml['tests'] = {}
+    for test in tests:
+        cur_test = {}
+        cur_test['id'        ] = test.id
+        cur_test['name'      ] = test.name
+        cur_test['set'       ] = test.set
+        cur_test['test_group'] = test.test_group.name
+        cur_test['seed'      ] = test.seed
+        cur_test['args'      ] = []
+        for arg in test.args:
+            cur_test['args'].append(arg)
+        tests_yml['tests'][str(test.id)] = cur_test
+    try:
+        with open(tests_yml_path, 'w') as yml_file:
+            yaml.dump(tests_yml, yml_file)
+    except Exception as e:
+        common.fatal(f"Failed to write tests.yml: {e}")
+    return tests_yml_path
+
+
+def update_tests_yml(tests_yml_path, ip, target_name, test_suite, regression, sim_jobs, timestamp_end, dry_mode):
+    ip_str = f"{ip.vendor}/{ip.name}"
+    ip_dir_name = f"{ip.vendor}__{ip.name}"
+    
+    sim_jobs_by_id = {}
+    for sim_job in sim_jobs:
+        sim_jobs_by_id[str(sim_job.id)] = sim_job
+    
+    tests_yml = None
+    try:
+        with open(tests_yml_path, 'r') as yamlfile:
+            tests_yml = yaml.load(yamlfile, Loader=SafeLoader)
+            if not tests_yml:
+                raise Exception(f"tests.yml is empty")
+            else:
+                tests_yml['timestamp_end'] = timestamp_end
+                for test_id in tests_yml['tests']:
+                    sim_job = sim_jobs_by_id[test_id]
+                    tests_yml['tests'][test_id]['timestamp_start'] = sim_job.timestamp_start
+                    tests_yml['tests'][test_id]['timestamp_end'  ] = sim_job.timestamp_end
+                    tests_yml['tests'][test_id]['results_path'] = sim_job.results_path
+                    tests_yml['tests'][test_id]['results_dir_name'] = sim_job.results_dir_name
+                    tests_yml['tests'][test_id]['sim_log_file_path'] = sim_job.sim_log_file_path
+        with open(tests_yml_path, 'w') as yml_file:
+            yaml.dump(tests_yml, yml_file)
+    except Exception as e:
+        common.fatal(f"Failed to update tests.yml: {e}")
+
+
 def print_end_of_regression_msg(ip, results, cov_report_path, test_suite, regression, sim_job_list, timestamp_start, timestamp_end):
     duration = timestamp_end - timestamp_start
     hours = math.floor(duration.total_seconds() / 3600)
